from bat.core.logger import logger
from bat.api.utils import config, job_name
from bat.libs.kubernetes import KubernetesClient
from bat.models.kubernetes import JobConfig, Container

__config = config()
BASE_COMMAND = [
    'bat',
    '--api',
    f'--argocd_url={__config.argocd_server}',
    f'--argocd_password={__config.argocd_password}',
    f'--argocd_user={__config.argocd_username}',
]
CLUSTER = __config.cluster
DOCKER_IMAGE = __config.docker_image
DEPLOY_CONFIG = __config.deploy_config
SERVICE_ACCOUNT = __config.service_account
DEPLOY_NAMESPACE = __config.deploy_namespace


def __create_job(name: str, command: list[str]):
    kctl = KubernetesClient()
    job = JobConfig(
        name=name,
        containers=[
            Container(
                name='bat',
                image=DOCKER_IMAGE,
                pull_policy='Never',
                command=command,
                config_map=DEPLOY_CONFIG,
            )
        ],
        restart='Never',
        service_account=SERVICE_ACCOUNT,
    )

    response = kctl.create_job(
        config=job,
        namespace=DEPLOY_NAMESPACE,
    )
    return response


def infra_job():
    command = BASE_COMMAND + ['-v']
    name = job_name('infra', CLUSTER)
    logger.info('Creating job config for infra test: %s', CLUSTER)
    return __create_job(name, command)


__all__ = ['infra_job']
