from bat.core.logger import logger
from bat.api.utils import config, job_name
from bat.api.models.status import JobStatus
from bat.libs.kubernetes import KubernetesClient


__config = config()
DEPLOY_NAMESPACE = __config.deploy_namespace
CLUSTER = __config.cluster


def __get_status(name: str):
    kctl = KubernetesClient()
    status = kctl.get_job_status(name=name, namespace=DEPLOY_NAMESPACE)
    job_status = JobStatus(
        active=status.active,
        failed=status.failed,
        succeeded=status.succeeded,
        ready=status.ready,
        start_time=str(status.start_time),
    )
    return job_status


def infra_job_status() -> JobStatus:
    job = job_name('infra', CLUSTER)
    logger.info('Getting job status for %s', job)
    return __get_status(job)


__all__ = ['infra_job_status']
