import os
import uvicorn
import logging
import pkg_resources

from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles

from bat.api.router import *
from bat.core.logger import Logger
from bat.core.definitions import LOGS_DIR, API_DIR


logger = logging.getLogger()


def init() -> FastAPI:
    app = FastAPI(
        title='Platform Business Acceptance Tests',
        version=pkg_resources.get_distribution("bat").version,
        docs_url='/',
        redoc_url='/docs',
    )
    app.include_router(jobs.router)
    app.include_router(reports.router)
    app.include_router(status.router)
    app.mount(
        '/static',
        StaticFiles(directory=os.path.join(API_DIR, 'static')),
        name='static',
    )

    Logger.setup_logger(os.path.join(LOGS_DIR, 'api.log'))
    logger.info("Initializing BAT API...")
    return app


app = init()


def start():
    uvicorn.run("bat.api.main:app", host="0.0.0.0", port=5151, reload=False)
