import json
from typing import Dict, Optional


class ImproperTestConfiguration(Exception):
    def __init__(self, message=None) -> None:
        error = (
            message
            if message is not None
            else "Test configuration file is not valid"
        )
        super().__init__(error)


class PollingTimeout(Exception):
    def __init__(self, mins: int, err: Optional[Dict] = None) -> None:
        super().__init__(
            f"Failed after polling for {mins} minutes \nerror: {json.dumps(err, indent=3)}"
        )


class GithubException(Exception):
    pass


class BadCredentials(GithubException):
    def __init__(self) -> None:
        super().__init__("Github Credentials are Invalid")


class RepositoryDoesNotExist(GithubException):
    def __init__(self, repo: str) -> None:
        super().__init__(f"Repository {repo} not found")


class InvalidCRD(GithubException):
    def __init__(self, msg: str) -> None:
        super().__init__(msg)


class ArgoCDException(Exception):
    pass


class ServerError(Exception):
    def __init__(
        self, url: Optional[str] = None, status_code: Optional[int] = None
    ) -> None:
        super().__init__(f"Cannot reach server :{url}:{status_code}:")


class ApplicationNotFound(ArgoCDException):
    def __init__(self, name: str) -> None:
        super().__init__(f"Application {name} not found")


class ArgoCDAPIError(ArgoCDException):
    def __init__(self, msg: str) -> None:
        super().__init__(msg)


class AwsException(Exception):
    pass


class BucketNotFound(AwsException):
    def __init__(self, name: str) -> None:
        super().__init__(f"Bucket {name} not found")


class BucketConfigurationError(AwsException):
    def __init__(self, name: str) -> None:
        super().__init__(f"Bucket {name} is empty")


class NoAvailableEvents(AwsException):
    def __init__(self, type: str) -> None:
        super().__init__(f"{type} as no available events")


class AwsConfigurationError(AwsException):
    def __init__(self) -> None:
        super().__init__("AWS Access Tokens are invalid")


class MapsorError(Exception):
    def __init__(self, asset: str) -> None:
        msg = f"Unable to reach mapsor to process: {asset}"
        super().__init__(msg)


class CrdError(Exception):
    def __init__(self, name: str) -> None:
        super().__init__(f"Error in {name} CRD")


class PubnubConfigurationError(Exception):
    def __init__(self) -> None:
        super().__init__("Pubnub keys incorrect")


class BucketFolderNotFound(Exception):
    def __init__(self, bucket: str, folder_path: str) -> None:
        super().__init__(f"folder {folder_path} not found in bucket {bucket}")


class KubernetesException(Exception):
    pass


class JobRunning(KubernetesException):
    def __init__(self, name: str) -> None:
        super().__init__(f"{name} job is still in running state")
