from pathlib import Path
from typing import Literal
from bat.core.logger import logger
from bat.models.account.crd import Spec
from bat.setups._models import SetupResource
from bat.extractors._extractor import BaseExtractor
from bat.extractors._account.cli import AccountCliExtractor
from bat.extractors._account.api import AccountApiExtractor
from bat.models.data import AccountData, AccountBucket, _Mapsor, _Karma


class AccountExtractor(BaseExtractor):
    def __new__(
        cls, path: SetupResource | Path, mode: Literal['api', 'cli']
    ) -> AccountData:
        if mode == 'cli':
            logger.info('Running Account CLI extractor...')
            spec = AccountCliExtractor(path)
        elif mode == 'api':
            logger.info('Running Account API extractor...')
            spec = AccountApiExtractor(path)
        else:
            raise NotImplementedError

        account_data = cls.extract_test_data(spec)
        return account_data

    @staticmethod
    def extract_test_data(spec: Spec) -> AccountData:
        logger.info('Extracting account data...')
        return AccountData(
            domain=spec.domain,
            bucket=AccountBucket(name=spec.s3.name, region=spec.s3.region),
            karma_config=_Karma(
                enabled=spec.config.enable_karma,
                url=spec.config.karma_url,
                secret=spec.config.karma_secret,
            ),
            mapsor=_Mapsor(
                mapsor_api=spec.config.mapsor.mapsor_api,
                xmorph_api=spec.config.mapsor.xmorph_api,
                queue=spec.config.mapsor.queue,
                token=spec.config.mapsor.token,
            ),
        )
