from pathlib import Path
from typing import Literal
from bat.core.logger import logger
from bat.models.channel.crd import Spec
from bat.setups._models import SetupResource
from bat.extractors._extractor import BaseExtractor
from bat.extractors._player.cli import PlayerCliExtractor
from bat.extractors._player.api import PlayerApiExtractor
from bat.models.data import PlayerData


class PlayerExtractor(BaseExtractor):
    def __new__(
        cls, path: SetupResource | Path, mode: Literal['api', 'cli']
    ) -> PlayerData:
        if mode == 'cli':
            logger.info('Running Player CLI extractor...')
            spec = PlayerCliExtractor(path)
        elif mode == 'api':
            logger.info('Running Player API extractor...')
            spec = PlayerApiExtractor(path)
        else:
            raise NotImplementedError

        account_data = cls.extract_test_data(spec)
        return account_data

    @staticmethod
    def extract_test_data(spec: Spec) -> PlayerData:
        logger.info('Extracting player data...')
        return PlayerData(
            feed_name=spec.name,
            feed_code=spec.channelCode,
            timezone=spec.timeZone,
            broadcast_start=spec.broadcastStartTime,
            cp_integration=spec.enableCpIntegration,
        )
