import time

from datetime import datetime

from pubnub.pnconfiguration import PNConfiguration
from pubnub.pubnub import PubNub

from bat.core.errors import PubnubConfigurationError
from bat.core.logger import Logger

logger = Logger('Pubnub')


class Pubnub:
    def __init__(self, publish_key, subscribe_key, secret_key) -> None:
        logger.info("Configuring PubNub")
        pnconfig = PNConfiguration()
        pnconfig.subscribe_key = subscribe_key
        pnconfig.publish_key = publish_key
        pnconfig.secret_key = secret_key
        pnconfig.user_id = "ieg_platform_bat"
        pnconfig.ssl = True

        try:
            self.pubnub = PubNub(pnconfig)
        except Exception as e:
            logger.info("Error in pubnub keys", exc_info=True)
            raise PubnubConfigurationError from e
        logger.info('Pubnub configuration complete')

    def fetch_messages(self, topic: str, from_time: int) -> list:
        logger.info("Fetching messages from topic: %s", topic)
        res = []
        resp = (
            self.pubnub.fetch_messages()
            .channels([topic])
            .include_message_actions(True)
            .start(from_time)
            .end(int(time.time()))
            .count(500)
            .sync()
        )

        envelope = resp.result
        for _ in range(10):
            try:
                if envelope.channels.get(topic) is not None:
                    for message in envelope.channels[topic]:
                        res.append(
                            {
                                "message": message.message,
                                "timetoken": datetime.fromtimestamp(int(message.timetoken) / 10000000),
                                "meta": message.meta,
                            }
                        )

                    return res
                logger.info("Topic not found yet...")
            except Exception as e:
                raise PubnubConfigurationError from e
            time.sleep(5)

        raise Exception(f'Pubnub topic {topic} not found')
