import yaml
import json
import logging

from pathlib import Path
from typing import Literal
from ruamel.yaml import YAML
from functools import lru_cache

logger = logging.getLogger()

YamlParser = Literal['ruamel', 'pyyaml']


def read_yaml(path: Path, parser: YamlParser = 'pyyaml'):
    logger.info("Reading yaml %s", str(path))
    with open(path, 'r') as file:
        if parser == 'pyyaml':
            data = yaml.safe_load(file)
        elif parser == 'ruamel':
            yaml_ = YAML()
            data = yaml_.load(file)
        else:
            raise NotImplementedError('yaml parser not implemented')
    return data


def load_yaml(data: object, parser: YamlParser):
    if parser == 'pyyaml':
        loaded = yaml.safe_load(data)
    elif parser == 'ruamel':
        yaml_ = YAML()
        loaded = yaml_.load(data)
    return loaded


def write_yaml(path: Path, data: dict, parser: YamlParser = 'pyyaml'):
    logger.info("Writing yaml %s", str(path))
    with open(path, 'w') as file:
        if parser == 'pyyaml':
            yaml.dump(data, file)
        elif parser == 'ruamel':
            yaml_ = YAML()
            yaml_.dump(data, file)
        else:
            raise NotImplementedError


def read_json(path: Path):
    logger.info("Reading json %s", str(path))
    with open(path, 'r') as file:
        data = json.load(file)
    return data


def write_json(path: Path, obj):
    logger.info("Writing json %s", str(path))
    with open(path, 'w') as file:
        json.dump(obj, file, indent=2)


@lru_cache
def cached_read_json(path: Path):
    logger.info('Reading json %s to cache', str(path))
    with open(path, 'r') as file:
        data = json.load(file)
    return data
