import json

from typing import Any
from pydantic import BaseModel, root_validator

from bat.core.errors import InvalidCRD
from bat.models.account._config import AccountConfig


class Metadata(BaseModel):
    name: str
    annotations: Any | None
    creationTimestamp: Any | None
    finalizers: Any | None
    generation: int | None
    labels: Any | None
    managedFields: Any | None
    name: str | None
    namespace: str | None
    resourceVersion: str | None
    uid: str | None


class S3(BaseModel):
    name: str
    region: str
    processedPath: str
    createIngestKeys: bool


class Spec(BaseModel):
    name: str
    domain: str
    storage: str
    amgId: str
    customerName: str
    hostName: str
    s3: S3
    config: AccountConfig

    @root_validator(pre=True)
    def serialize(cls, value):
        try:
            value['config'] = AccountConfig(**json.loads(value['config']))
        except Exception as e:
            raise InvalidCRD('Invalid config in account CRD') from e
        return value


class CRD(BaseModel):
    apiVersion: str
    kind: str
    metadata: Metadata
    spec: Spec
