import json

from typing import Any
from bat.libs.utils import load_yaml
from bat.core.errors import InvalidCRD
from bat.models.blip._config import CRDConfig
from bat.models.blip._automation import CRDAutomation
from pydantic import BaseModel, Field, root_validator


class Metadata(BaseModel):
    name: str
    annotations: Any | None
    creationTimestamp: Any | None
    finalizers: Any | None
    generation: int | None
    labels: Any | None
    managedFields: Any | None
    name: str | None
    namespace: str | None
    resourceVersion: str | None
    uid: str | None


class Deployment(BaseModel):
    helmVersion: str


class Customer(BaseModel):
    name: str
    hostName: str
    rootDomain: str
    adminEmail: str
    supportEmail: str


class Tags(BaseModel):
    amagiId: str
    phase: str
    geo: str


class Spec(BaseModel):
    deployment: Deployment
    customer: Customer
    tags: Tags
    config: CRDConfig
    cp_automation: CRDAutomation = Field(alias='cp-automation')

    @root_validator(pre=True)
    def serialize(cls, value):
        try:
            value['config'] = CRDConfig(**json.loads(value['config']))
        except Exception as e:
            raise InvalidCRD(
                "Invalid json found at spec:config in blip CRD"
            ) from e
        try:
            value['cp-automation'] = CRDAutomation(
                **load_yaml(value['cp-automation'], 'pyyaml')
            )
        except Exception as e:
            raise InvalidCRD(
                "Invalid yaml found at spec:cp-automation in blip CRD"
            ) from e
        return value


class CRD(BaseModel):
    apiVersion: str
    kind: str
    metadata: Metadata
    spec: Spec
