from typing import Any
from pydantic import BaseModel, Field


class Chart(BaseModel):
    chartName: str
    chartVersion: str


class AutomationImages(BaseModel):
    blipImage: str
    monitoringImage: str
    alankaraImage: str
    postmasterImage: str
    dynamiteImage: str
    cp_integration_sidecarImage: str
    tinkerImage: str
    sentinelImage: str


class AutomationServerless(BaseModel):
    xmorphImage: str
    mapsorImage: str
    alteroImage: str


class Automation(BaseModel):
    charts: list[Chart]
    dockerImages: AutomationImages
    serverless: AutomationServerless


class PlayoutImages(BaseModel):
    playerImage: str
    tardisImage: str
    switcherImage: str
    switcherControllerImage: str
    doordarshanImage: str
    zixiImage: str
    redisImage: str
    transcoderImage: str
    cacherImage: str
    sdcImage: str
    delayServerImage: str
    capsequoImage: str
    fluentdImage: str
    metricsHandlerImage: str
    tarangImage: str
    targonImage: str
    targonControllerImage: str
    muxerImage: str
    demuxerImage: str


class Playout(BaseModel):
    charts: list[Chart]
    dockerImages: PlayoutImages
    serverless: dict[str, Any]


class LiveImages(BaseModel):
    sauronDockerImage: str
    elicdpDockerImage: str
    elicplusplusDockerImage: str
    elicDockerImage: str
    servoDockerImage: str
    epubDockerImage: str
    transcoderDockerImage: str
    vodorDockerImage: str
    ecrCronJobImage: str
    rtpfec2udpDockerImage: str
    udp2srtDockerImage: str
    srt2udpDockerImage: str
    s32udpDockerImage: str
    udp2webrtcDockerImage: str
    udp2webrtc_esDockerImage: str
    tr07_to_ndijxsDockerImage: str
    ddDockerImage: str
    playerDockerImage: str
    relay_controllerDockerImage: str
    relay_rtpfec2udpDockerImage: str
    relay_udp2srtDockerImage: str
    relay_srt2rtpDockerImage: str
    recorder_captureDockerImage: str
    controller_transcoderDockerImage: str
    packagerDockerImage: str
    transdecoderDockerImage: str
    switcherDockerImage: str
    lmcDockerImage: str


class Live(BaseModel):
    charts: list[Chart]
    dockerImages: LiveImages
    serverless: dict[str, Any]


class PlecImages(BaseModel):
    plecImage: str


class Plec(BaseModel):
    charts: list
    dockerImages: PlecImages
    serverless: dict[str, Any]


class PlatformImages(BaseModel):
    amagi_services_ServicesImage: str = Field(
        ..., alias='amagi-services_ServicesImage'
    )
    amagi_services_ControllerImage: str = Field(
        ..., alias='amagi-services_ControllerImage'
    )
    amagi_services_ServerlessImage: str = Field(
        ..., alias='amagi-services_ServerlessImage'
    )


class PlatformServerless(BaseModel):
    platform_resources_Image: str = Field(..., alias='platform-resources_Image')


class Platform(BaseModel):
    charts: list[Chart]
    dockerImages: PlatformImages
    serverless: PlatformServerless


class CpIntegrationImages(BaseModel):
    samyojakaImage: str
    postmasterImage: str
    chitrakaraImage: str
    sahityaImage: str
    cp_integration_postmasterSirius_sidecarImage: str = Field(
        ..., alias='cp-integration-postmasterSirius-sidecarImage'
    )
    cp_integration_samyojaka_sidecarImage: str = Field(
        ..., alias='cp-integration-samyojaka-sidecarImage'
    )


class CpIntegrationServerless(BaseModel):
    akashvaniImage: str
    siriusImage: str


class CpIntegration(BaseModel):
    charts: list[Chart]
    dockerImages: CpIntegrationImages
    serverless: CpIntegrationServerless


class Release(BaseModel):
    automation: Automation
    playout: Playout
    live: Live
    plec: Plec
    platform: Platform
    cp_integration: CpIntegration
