from pydantic import BaseModel
from bat.validators.base_config import PlatformConfig
from bat.validators.deploy_config import PubnubConfig
from bat.models.blip._config import IceServer


class PodConfig(BaseModel):
    name: str
    enabled: bool
    replicas: int


class CpAutomation(BaseModel):
    release: str
    pubnub: PubnubConfig


class BlipConfig(BaseModel):
    nexus_elasticache: str
    turnservers: list[IceServer]


class BlipData(BaseModel):
    existing: bool | None = True
    customer: str
    root_domain: str
    host_name: str
    epub_url: str
    cp_automation: CpAutomation
    config: BlipConfig


class AccountBucket(BaseModel):
    name: str
    region: str


class _Mapsor(BaseModel):
    mapsor_api: str
    xmorph_api: str
    queue: str
    token: str


class _Karma(BaseModel):
    enabled: bool
    url: str | None
    secret: str | None


class AccountData(BaseModel):
    existing: bool | None = True
    domain: str
    bucket: AccountBucket
    mapsor: _Mapsor
    karma_config: _Karma


class PlayerData(BaseModel):
    existing: bool | None = True
    feed_name: str
    feed_code: str
    timezone: str
    broadcast_start: str
    cp_integration: bool


class TestData(BaseModel):
    platform_config: PlatformConfig
    blip_data: BlipData | None
    account_data: AccountData | None
    player_data: PlayerData | None


class KubernetesSecret(BaseModel):
    name: str
    value: str
