#GitCreds: {
    repo: string | *"argocd_deploy"
    user: string
    email: string
    password: string
    org: string | *"amagimedia"
}

#ArgoCreds: {
    server: string
    username: string
    password: string
}

#PlatformConfig: {
    cp_orchestration: bool | *false
    cluster: string
    stage: string
    cloud: "aws" | "gcp"
    region: string
    profile: string
}

#PlatformRelease: {
    version: string
    repo: string | *"platform-resources"
    blip_template_path: string | *"crds/aws/blip.yaml"
    account_template_path: string | *"crds/aws/account.yaml"
}

#CpRelease: {
    version: string
    repo: string | *"cloudport"
    path: string | *"releases.yaml"
}

#TurnServer: {
    url: string
    username: string
    password: string
}

#Pubnub: {
    publish_key: string
    subscriber_key: string
    secret_key: string
}

#CpLivePubnub: {
    publish_key: string
    subscriber_key: string
}

#CustomTemplate: {
    repo: string
    org: string
    path: string
    branch: string
}

#BlipConfig: {
    hosted_zone: string
    admin_email: string
    support_email: string
    custom_blip_template: bool
    turn_server?: #TurnServer
    pubnub?: #Pubnub
    cplive_pubnub?: #CpLivePubnub
    if custom_blip_template {
        blip_template: #CustomTemplate
    }
}

#AccountConfig: {
    s3_bucket: string
    mapsor_api: string
    mapsor_token: string
    queue: string
    xmorph: string
    custom_account_template: bool
    if custom_account_template {
        account_template: #CustomTemplate
    }
}

#AdhConfig: {
    configure: #AdhConfigure
    input_data: #AdhInput
    pull_template: string
    adhtool_path: string
}

#AdhConfigure: {
    branch: string
    repo_type: "github" | "codecommit"
    repo_url: string
    bucket: string
    aws_profile: string
    aws_region: string
}

#AdhInput: {
    operator_email: string
    region: string
    timezone: string
    vpc_zone: string
    dns_domain: string
    channel_name: string
    channel_id: int
    chart_museum_endpoint: string
    sdc_bucket: string
   ecr_url: string
}

#ScenarioConfig: {
    media_asset: string | *"e2e-file.mxf"
    graphics_asset: string | *"e2e-graphic.zip"
    timezone: string | *"US/Eastern"
}

git_config: #GitCreds
cluster_connection: "argocd" | "kubernetes" | *"kubernetes" @cs(prompt=true)
if cluster_connection == "argocd" {
    argocd_config: #ArgoCreds
}

platform_config: #PlatformConfig
scenario: #ScenarioConfig

deploy_blip: bool | *false @cs(prompt=true)
if deploy_blip {
    blip_config: #BlipConfig
    platform_release: #PlatformRelease
    cp_release: #CpRelease
}

deploy_account: bool | *false @cs(prompt=true)
if deploy_account  {
    account_config: #AccountConfig
    platform_release: #PlatformRelease
    cp_release: #CpRelease
}

deploy_channel: bool | *false @cs(prompt=true)
if deploy_channel{
    adh_config: #AdhConfig
    platform_release: #PlatformRelease
    cp_release: #CpRelease
}

existing_setup: {
    if !deploy_blip {
        customer: string
        blip_file: string | *"blip.yaml"
         if !deploy_account {
            account_file: string |*"account.yaml"
            if !deploy_channel {
                channel_code: string
            }
        }
    }
}
