import os
import json
import base64
import requests

from pathlib import Path


def send_results(allure_server: str, allure_dir: Path, customer: str):
    files = os.listdir(allure_dir)
    results = []
    for file in files:
        result = {}
        file_path = os.path.join(allure_dir, file)

        if os.path.isfile(file_path):
            try:
                with open(file_path, 'rb') as f:
                    content = f.read()
                    if content.strip():
                        b64_content = base64.b64encode(content)
                        result['file_name'] = file
                        result['content_base64'] = b64_content.decode('UTF-8')
                        results.append(result)
            finally:
                f.close()

    headers = {'Content-type': 'application/json'}
    request_body = json.dumps({'results': results})

    endpoint = allure_server.rstrip('/') + "/send-results"
    params = {"project_id": customer, "force_project_creation": "true"}
    response = requests.post(
        endpoint,
        headers=headers,
        params=params,
        data=request_body,
        verify=True,
    )

    return response


def generate_report(
    allure_server: str, customer: str, exec_from: str, exec_type: str
):
    endpoint = allure_server.rstrip('/') + "/generate-report"
    params = {
        "project_id": customer,
        "execution_name": customer,
        "execution_from": exec_from,
        "execution_type": exec_type,
    }
    response = requests.get(endpoint, params=params, verify=True)
    return response
