import os
from pathlib import Path
from bat.core.logger import logger
from bat.setups._setup import Setup
from bat.models.data import BlipData
from bat.models.cp_release import Release
from bat.extractors import AccountExtractor
from bat.setups._models import SetupResource
from bat.core.definitions import TEST_CONFIG


class AccountSetup(Setup):
    def __init__(
        self, blip_data: BlipData, config_path: Path = TEST_CONFIG
    ) -> None:
        super().__init__(config_path)
        platform_config = self.test_config.platform_config

        if (
            self.test_config.exec_mode == 'cli'
            and self.test_config.deploy_account
        ):
            ...
        elif (
            self.test_config.exec_mode == 'cli'
            and not self.test_config.deploy_account
        ):
            logger.info(
                'Executing in cli mode for existing account',
            )
            account_path = Path(
                os.path.join(
                    self.working_dir,
                    self.git_config.repo,
                    platform_config.stage,
                    'deployment',
                    'operator',
                    f"{platform_config.cloud}-{self.get_region_short(platform_config.region, platform_config.cloud)}",
                    platform_config.cluster,
                    f"{blip_data.customer}-automation",
                    'account',
                    'account.yaml',
                )
            )
            self.__account_data = AccountExtractor(account_path, mode='cli')
        else:
            logger.info(
                'Executing in api mode for existing account: %s',
                self.test_config.existing_account,
            )
            account_path = SetupResource(
                resource='accounts',
                namespace=f"{blip_data.customer}-automation",
                name=self.test_config.existing_account,
            )
            self.__account_data = AccountExtractor(account_path, mode='api')

    @property
    def data(self):
        return self.__account_data

    def create_template(self, platform_release, cp_release: Release):
        ...

    def git_deploy(self, template):
        ...
