import os

from pathlib import Path

from bat.core.logger import logger
from bat.setups._setup import Setup
from bat.setups._models import SetupResource
from bat.extractors import BlipExtractor
from bat.models.cp_release import Release
from bat.core.definitions import TEST_CONFIG


class BlipSetup(Setup):
    def __init__(self, config_path: str = TEST_CONFIG) -> None:
        super().__init__(config_path)
        platform_config = self.test_config.platform_config
        if self.test_config.exec_mode == 'cli' and self.test_config.deploy_blip:
            logger.info('Setting up new automation')
            cp_release = self.read_template(
                self.test_config.cp_release, Release
            )
            platform_release = self.read_template(
                self.test_config.platform_release
            )
            template = self.create_template(platform_release, cp_release)
            self.git_deploy(template)
        elif (
            self.test_config.exec_mode == 'cli'
            and not self.test_config.deploy_blip
        ):
            logger.info(
                'Executing in cli mode for existing blip: %s',
                self.test_config.existing_blip,
            )
            blip_path = Path(
                os.path.join(
                    self.working_dir,
                    self.git_config.repo,
                    platform_config.stage,
                    'deployment',
                    'operator',
                    f"{platform_config.cloud}-{self.get_region_short(platform_config.region, platform_config.cloud)}",
                    platform_config.cluster,
                    f"{self.test_config.existing_blip}-automation",
                    'automation',
                    'blip.yaml',
                )
            )
            self.__blip_data = BlipExtractor(blip_path, 'cli')
        else:
            logger.info(
                'Executing in api mode for existing blip: %s',
                self.test_config.existing_blip,
            )
            customer = self.test_config.existing_blip
            blip_path = SetupResource(
                resource='automations',
                namespace=f"{customer}-automation",
                name=customer,
            )
            self.__blip_data = BlipExtractor(blip_path, 'api')

    @property
    def data(self):
        return self.__blip_data

    def create_template(self, platform_release, cp_release: Release):
        ...

    def git_deploy(self, template):
        ...
