import os

from pathlib import Path
from bat.core.logger import logger
from bat.models.cp_release import Release
from bat.setups._setup import Setup
from bat.setups._models import SetupResource
from bat.extractors import PlayerExtractor
from bat.models.data import BlipData, AccountData


class PlayerSetup(Setup):
    def __init__(
        self,
        blip_data: BlipData,
        account_data: AccountData,
        config_path: Path,
    ) -> None:
        super().__init__(config_path)
        platform_config = self.test_config.platform_config

        if (
            self.test_config.exec_mode == 'cli'
            and self.test_config.deploy_player
        ):
            ...
        elif (
            self.test_config.exec_mode == 'cli'
            and not self.test_config.deploy_player
        ):
            logger.info(
                'Executing in cli mode for existing channel: %s',
                self.test_config.existing_channel,
            )
            channel_file = f"{blip_data.customer}-{account_data.domain}-{self.test_config.existing_channel}.yaml"
            player_path = Path(
                os.path.join(
                    self.working_dir,
                    self.git_config.repo,
                    platform_config.stage,
                    'deployment',
                    'operator',
                    f"{platform_config}-{self.get_region_short(platform_config.region, platform_config.cloud)}",
                    platform_config.cluster,
                    f"{blip_data.customer}-automation",
                    'channel',
                    channel_file,
                )
            )

            self.__player_data = PlayerExtractor(player_path, mode='cli')
        else:
            logger.info(
                'Executing in api mode for existing channel: %s',
                self.test_config.existing_channel,
            )
            player_path = SetupResource(
                resource='channels',
                namespace=f"{blip_data.customer}-automation",
                name=f"{account_data.domain}-{self.test_config.existing_channel}",
            )

            self.__player_data = PlayerExtractor(player_path, mode='api')

    @property
    def data(self):
        return self.__player_data

    def create_template(self, platform_release, cp_release: Release):
        ...

    def git_deploy(self, template):
        ...
