import os
import pytest

from pathlib import Path
from bat.core.logger import logger
from bat.setups import SetupFactory
from bat.libs.utils import read_json
from bat.models.config import Config
from bat.core.definitions import TEST_CONFIG, LOGS_DIR
from bat.scripts.report_handler import send_results, generate_report


@pytest.fixture(scope='session', autouse=True)
def setup() -> SetupFactory:
    yield SetupFactory(upto='infra')


def pytest_sessionfinish(session, exitstatus):
    config = Config(**read_json(TEST_CONFIG))
    customer = os.environ.get('CUSTOMER', 'default')
    allure_dir = Path(os.path.join(LOGS_DIR, 'allure-results'))
    if config.base_config.allure_server:
        response = send_results(
            config.base_config.allure_server,
            allure_dir,
            customer,
        )
        if response.ok:
            logger.info(
                'Report sent successfully to %s',
                config.base_config.allure_server,
            )
            response = generate_report(
                config.base_config.allure_server,
                customer,
                customer,
                config.base_config.platform_config.environment,
            )
            if response.ok:
                logger.info('Report generated successfully')
            else:
                logger.info(response.json())
        else:
            logger.info(response.json())
