import pytest

from bat.core.logger import logger
from bat.setups import SetupFactory
from bat.core.errors import PollingTimeout


class TestPrerequisites:
    ...


class TestPlatformConfiguration:
    ...


@pytest.mark.evt
class TestPlatformComponents:
    @staticmethod
    def test_grafana_health(setup: SetupFactory):
        """Polling grafana application health status"""
        logger.info("Testing Grafana health")
        if setup.test_data.platform_config.environment == 'prod':
            app = 'grafana-prod'
        else:
            app = 'grafana'

        try:
            health = setup.argocd.poll_app_health(app_name=app)
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"

    @staticmethod
    def test_loki_health(setup: SetupFactory):
        """Polling loki application health status"""
        logger.info("Testing Loki health")
        if setup.test_data.platform_config.environment == 'prod':
            app = 'loki-prod'
        else:
            app = 'loki'
        try:
            health = setup.argocd.poll_app_health(app_name=app)
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"

    @staticmethod
    def test_promtail_health(setup: SetupFactory):
        """Polling promtail application health status"""
        logger.info("Testing Promtail health")
        try:
            health = setup.argocd.poll_app_health(app_name="promtail")
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"

    @staticmethod
    def test_clustersync_health(setup: SetupFactory):
        """Polling cluster-sync application health status"""
        logger.info("Testing cluster-sync health")
        if setup.test_data.platform_config.environment == 'prod':
            app = 'cluster-sync-prod'
        else:
            app = 'cluster-sync'

        try:
            health = setup.argocd.poll_app_health(app_name=app)
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"

    @staticmethod
    def test_keda_health(setup: SetupFactory):
        """Polling keda application health status"""
        logger.info("Testing keda health")
        if not setup.test_data.platform_config.enterprise:
            app = f"keda-{setup.test_data.platform_config.cluster}"
        else:
            app = 'keda'
        try:
            health = setup.argocd.poll_app_health(app_name=app)
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"

    @staticmethod
    def test_cp_cluster_bootstrap_health(setup: SetupFactory):
        """Polling cp-cluster-bootstrap application health status"""
        logger.info("Testing cp-cluster-bootstrap health")
        cluster = setup.test_data.platform_config.cluster
        app = f'cp-cluster-bootstrap-{cluster}'
        try:
            health = setup.argocd.poll_app_health(app_name=app)
            assert health == "Healthy"
        except PollingTimeout as e:
            assert False, f"Unexpected error occured: {e}"
